namespace Application.Abstractions.Chat;

public interface IChatHubClient
{
    Task ReceiveMessage(ChatMessage message);
    Task ReceiveHistory(IReadOnlyList<ChatMessage> messages);
    Task ReceiveSystemMessage(string message);
    Task ReceiveParticipantCount(int count);
    Task ReceiveParticipants(IReadOnlyList<ChatParticipant> participants);
    Task Connected(string message);
    Task Logout(string message);
    Task Kick();
}